| Title: | iSEE for the Bioconductor ExperimentHub |
|---|---|
| Description: | This package defines a custom landing page for an iSEE app interfacing with the Bioconductor ExperimentHub. The landing page allows users to browse the ExperimentHub, select a data set, download and cache it, and import it directly into a Bioconductor iSEE app. |
| Authors: | Kevin Rue-Albrecht [aut, cre] (ORCID: <https://orcid.org/0000-0003-3899-3872>) |
| Maintainer: | Kevin Rue-Albrecht <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.15.0 |
| Built: | 2026-05-31 08:02:28 UTC |
| Source: | https://github.com/bioc/iSEEhub |
iSEEhub app
iSEEhub(ehub, runtime_install = FALSE)iSEEhub(ehub, runtime_install = FALSE)
ehub |
An |
runtime_install |
A logical scalar indicating whether the app may allow
users whether to install data set dependencies at runtime using
|
An iSEE() app with a custom landing page interfacing with ehub.
library(ExperimentHub) ehub <- ExperimentHub() app <- iSEEhub(ehub) if (interactive()) { shiny::runApp(app, port = 1234) }library(ExperimentHub) ehub <- ExperimentHub() app <- iSEEhub(ehub) if (interactive()) { shiny::runApp(app, port = 1234) }